'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }(); /**
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      * Created by tonyjiang on 16/3/15.
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      */


var _chanjetEnvCheck = require('chanjet-env-check');

var _chanjetEnvCheck2 = _interopRequireDefault(_chanjetEnvCheck);

var _PluginManager = require('./PluginManager');

var _PluginManager2 = _interopRequireDefault(_PluginManager);

var _nativeConfig = require('./native-config');

var _nativeConfig2 = _interopRequireDefault(_nativeConfig);

var _eventemitter = require('eventemitter2');

var _eventemitter2 = _interopRequireDefault(_eventemitter);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/**
 * 应用预处理类 , 在应用加载前 , 解决各种环境检测 , nativeAPI状态.
 * @author TonyJiang
 */
var Mutants = function () {
    function Mutants() {
        var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

        _classCallCheck(this, Mutants);

        this.emitter = new _eventemitter2.default();


        /**
         * 环境对象
         * @type {EnvClass}
         * @typeof {}
         *
         * @property browser {String} 当前浏览器 , 取值范围请参考constant.browser
         * @property os {String}  当前操作系统 , 取值范围请参考constant.os
         * @property platform {String}  当前平台 , 取值范围请参考constant.platform
         *
         * @property constant {JSONObject} 环境常量 , 用来当作环境判断的对比值
         *
         *      @property constant.browser {JSONObject} 浏览器常量
         *          @property constant.browser.chrome {String} chrome浏览器
         *          @property constant.browser.firefox {String} firefox浏览器
         *          @property constant.browser.ie {String} ie浏览器
         *          @property constant.browser.opera {String} opera浏览器
         *          @property constant.browser.safari {String} safari浏览器
         *          @property constant.browser.unknown {String} unknown浏览器
         *
         *      @property constant.os {JSONObject} 操作系统常量
         *          @property constant.os.android {String}  安卓操作系统
         *          @property constant.os.ios {String}  ios操作系统
         *          @property constant.os.computer {String}  PC机
         *          @property constant.os.mobile {String}  手机
         *
         *      @property constant.platform {JSONObject} 平台常量
         *          @property constant.platform.chanjet {String} 畅捷通平台
         *          @property constant.platform.weixin {String} 微信平台
         *          @property constant.platform.browser {String} 浏览器 , 一般是开发环境
         *
         *
         */
        this._env = _chanjetEnvCheck2.default;

        /**
         * 准备工作是否ready
         * @type {boolean}
         * @private
         */
        this._isReady = false;

        this.config(options);
    }

    _createClass(Mutants, [{
        key: 'init',
        value: function init() {
            this._ready();
        }
    }, {
        key: 'config',
        value: function config(options) {
            /**
             * 设置参数
             * @type {JSONObject}
             *  @property plugins {Array}   所需要插件, 需要使用require返回插件class
             *  @property auth  认证信息
             *      @property auth.chanjet {JSONObject}  chanjet平台认证信息
             *      @property auth.weixin {JSONObject}   微信平台认证信息 , 详见微信开发文档
             *          @property auth.weixin.appId {String}
             *          @property auth.weixin.timestamp {String}
             *          @property auth.weixin.nonceStr {String}
             *          @property auth.weixin.signature {String}
             *
             * @example
             * options = {
             *      plugins : [
             *          require('chanjet-plugin-base'),
             *          require('chanjet-plugin-sms'),
             *          require('chanjet-plugin-share')
             *      ],
             *
             *      auth : {
             *          chanjet : {},
             *          weixin : {
             *              appId : 'insert appId here',
             *              timestamp : '1458198827123',
             *              nonceStr : 'dwqq2321321',
             *              signature : 'qq2233'
             *          }
             *      }
             * }
             */
            this._options = Object.assign({}, options);
        }

        /**
         * 等待环境ready , 成功后回调callback
         * @param {Function} callback 成功后执行的回调
         */

    }, {
        key: 'ready',
        value: function ready(callback) {
            if (this._isReady) {
                callback();
            } else {
                this.emitter.on(Mutants.EVENT_NAME.READY, callback);
            }
        }

        /**
         * 从后台切回来时触发
         * @param {Function} callback
         */

    }, {
        key: 'resume',
        value: function resume(callback) {
            this.emitter.on(Mutants.EVENT_NAME.RESUME, callback);
        }
    }, {
        key: 'suspend',
        value: function suspend(callback) {
            this.emitter.on(Mutants.EVENT_NAME.SUSPEND, callback);
        }

        /**
         * 退出当前APP ,暂时不做回调处理
         */

    }, {
        key: 'exit',
        value: function exit() {
            cordova.exec(function () {}, function () {}, 'Destroy', 'destroy', []);
        }

        /**
         * 具体处理ready方法, 由实现类重写
         * @private
         */

    }, {
        key: '_ready',
        value: function _ready() {}
    }, {
        key: 'env',
        get: function get() {
            return this._env;
        }
    }, {
        key: 'constant',
        get: function get() {
            return this._env.constant;
        }
    }, {
        key: 'plugin',
        get: function get() {
            return _PluginManager2.default;
        }
    }, {
        key: 'nativeConfig',
        get: function get() {
            return _nativeConfig2.default.instance;
        }

        //为了android提供, 检测当前是否为restore状态

    }, {
        key: 'isRestore',
        get: function get() {
            return false;
        }

        //为了android提供, 获取restore状态下上次plugin的数据

    }, {
        key: 'restorePluginData',
        get: function get() {
            return {};
        }
    }]);

    return Mutants;
}();

Mutants.EVENT_NAME = {
    READY: 'ready',
    RESUME: 'resume',
    SUSPEND: 'suspend'
};
exports.default = Mutants;